<?php

namespace Annie\Acts\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Acts\Http\Requests\ActivityLogRequest;
use Annie\Acts\Interfaces\ActivityLogRepositoryInterface;
use Annie\Acts\Models\ActivityLog;

/**
 * Resource controller class for activity_log.
 */
class ActivityLogResourceController extends BaseController
{

    /**
     * Initialize activity_log resource controller.
     *
     * @param type ActivityLogRepositoryInterface $activity_log
     *
     * @return null
     */
    public function __construct(ActivityLogRepositoryInterface $activity_log)
    {
        parent::__construct();
        $this->repository = $activity_log;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Acts\Repositories\Criteria\ActivityLogResourceCriteria::class);
    }

    /**
     * Display a list of activity_log.
     *
     * @return Response
     */
    public function index(ActivityLogRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Acts\Repositories\Presenter\ActivityLogPresenter::class)
                ->$function();
        }

        $activity_logs = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('acts::activity_log.names'))
            ->view('acts::activity_log.index', true)
            ->data(compact('activity_logs', 'view'))
            ->output();
    }

    /**
     * Display activity_log.
     *
     * @param Request $request
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function show(ActivityLogRequest $request, ActivityLog $activity_log)
    {

        if ($activity_log->exists) {
            $view = 'acts::activity_log.show';
        } else {
            $view = 'acts::activity_log.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('acts::activity_log.name'))
            ->data(compact('activity_log'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_log.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityLogRequest $request)
    {

        $activity_log = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('acts::activity_log.name')) 
            ->view('acts::activity_log.create', true) 
            ->data(compact('activity_log'))
            ->output();
    }

    /**
     * Create new activity_log.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityLogRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_log                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('acts::activity_log.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('acts/activity_log/' . $activity_log->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/acts/activity_log'))
                ->redirect();
        }

    }

    /**
     * Show activity_log for editing.
     *
     * @param Request $request
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function edit(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('acts::activity_log.name'))
            ->view('acts::activity_log.edit', true)
            ->data(compact('activity_log'))
            ->output();
    }

    /**
     * Update the activity_log.
     *
     * @param Request $request
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function update(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        try {
            $attributes = $request->all();

            $activity_log->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('acts::activity_log.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('acts/activity_log/' . $activity_log->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('acts/activity_log/' . $activity_log->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_log.
     *
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function destroy(ActivityLogRequest $request, ActivityLog $activity_log)
    {
        try {

            $activity_log->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('acts::activity_log.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('acts/activity_log/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('acts/activity_log/' . $activity_log->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_log.
     *
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function delete(ActivityLogRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('acts::activity_log.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('acts/activity_log'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/acts/activity_log'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_logs.
     *
     * @param Model   $activity_log
     *
     * @return Response
     */
    public function restore(ActivityLogRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('acts::activity_log.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/acts/activity_log'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/acts/activity_log/'))
                ->redirect();
        }

    }

}
